@@ -10,7 +10,7 @@ func main() {
 	k3d := cmd.NewCmdK3d()
 	k3d.DisableAutoGenTag = true
 
-	if err := doc.GenMarkdownTree(k3d, "../docs/usage/commands"); err != nil {
+	if err := doc.GenMarkdownTree(k3d, "./docs/usage/commands"); err != nil {
 		l.Log().Fatalln(err)
 	}
 }
